@@ -40,6 +40,7 @@ class Client(object):
         policy = PutPolicy()
         policy.set_conf('scope', '%s:%s' % (bucket,key))
         policy.dump_policy(self.cfg)
+        print(policy.putpolicy)
         token = self.auth.uploadtoken(policy.putpolicy)
         return self.simpleupload.upload(path,token)
 
@@ -65,7 +66,11 @@ class Client(object):
             pre = ''
         
         try:
-            m = mode or int(self.cfg.mode)
+            # m = mode or int(self.cfg.mode)
+            if mode == None:
+                m = int(self.cfg.mode)
+            else:
+                m = int(mode)
         except Exception:
             m = ''
         
@@ -91,10 +96,18 @@ class Client(object):
     def delete(self,bucket,key):
         return self.bmgr.delete(bucket,key)
 
-    def move(self,srcbucket, srckey, dstbucket, dstkey):
+    def move(self,srcbucket, srckey, dstbucket, dstkey=''):
+        if dstkey:
+            pass
+        else:
+            dstkey = srckey
         return self.bmgr.move(srcbucket, srckey, dstbucket, dstkey)
 
-    def copy(self,srcbucket, srckey, dstbucket, dstkey):
+    def copy(self,srcbucket, srckey, dstbucket, dstkey=''):
+        if dstkey:
+            pass
+        else:
+            dstkey = srckey
         return self.bmgr.copy(srcbucket, srckey, dstbucket, dstkey)
 
     def setdeadline(self,bucket,key,deadline):
